package com.ruoyi.baseinfo.mapper;

import java.util.List;
import com.ruoyi.baseinfo.domain.BasePlandetailInfo;

/**
 * 计划明细Mapper接口
 * 
 * @author CaesarBao
 * @date 2020-10-23
 */
public interface BasePlandetailInfoMapper 
{
    /**
     * 查询计划明细
     * 
     * @param objid 计划明细ID
     * @return 计划明细
     */
    public BasePlandetailInfo selectBasePlandetailInfoById(Long objid);

    /**
     * 查询计划明细列表
     * 
     * @param basePlandetailInfo 计划明细
     * @return 计划明细集合
     */
    public List<BasePlandetailInfo> selectBasePlandetailInfoList(BasePlandetailInfo basePlandetailInfo);

    /**
     * 新增计划明细
     * 
     * @param basePlandetailInfo 计划明细
     * @return 结果
     */
    public int insertBasePlandetailInfo(BasePlandetailInfo basePlandetailInfo);

    /**
     * 修改计划明细
     * 
     * @param basePlandetailInfo 计划明细
     * @return 结果
     */
    public int updateBasePlandetailInfo(BasePlandetailInfo basePlandetailInfo);

    /**
     * 删除计划明细
     * 
     * @param objid 计划明细ID
     * @return 结果
     */
    public int deleteBasePlandetailInfoById(Long objid);

    /**
     * 批量删除计划明细
     * 
     * @param objids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBasePlandetailInfoByIds(String[] objids);
}
